/*
 * Copyright 2002-2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.core.type.classreading;

import java.io.IOException;

import org.springframework.core.type.AbstractClassMetadataMemberClassTests;
import org.springframework.core.type.ClassMetadata;

/**
 * @author Chris Beams
 * @since 3.1
 * @see AbstractClassMetadataMemberClassTests
 */
public class ClassMetadataReadingVisitorMemberClassTests
		extends AbstractClassMetadataMemberClassTests {

	@Override
	public ClassMetadata getClassMetadataFor(Class<?> clazz) {
		try {
			MetadataReader reader =
				new SimpleMetadataReaderFactory().getMetadataReader(clazz.getName());
			return reader.getAnnotationMetadata();
		}
		catch (IOException ex) {
			throw new IllegalStateException(ex);
		}
	}

}
